==> ejc-budgetmanage-impl-3.0.0-20220328.024439-27-sources.jar: com/ejianc/business/bedget/vo/QuotadesignVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.business.record.vo.RecordquotadesignVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bedget.vo.QuotadesigndetailVO;

/**
 * 限额设计表
 * 
 * @author generator
 * 
 */
public class QuotadesignVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.math.BigDecimal costTotal; // 造价合计
    private java.math.BigDecimal laborTotal; // 人工费合计
    private java.math.BigDecimal materialTotal; // 材料费合计
    private java.math.BigDecimal mechanicalTotal; // 机械费合计
    private java.math.BigDecimal managementTotal; // 企业管理费合计
    private java.math.BigDecimal feesTotal; // 规费合计
    private java.math.BigDecimal taxTotal; // 税金合计
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.math.BigDecimal profitsTotal; // 利润合计

    private String innercode; // 内码
    
    private List<QuotadesigndetailVO> quotadesigndetailEntities = new ArrayList<>(); // 限额设计子表
    private List<RecordquotadesignVO> recordquotadesignList = new ArrayList<>(); // 历史信息

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 造价合计
     */
    public java.math.BigDecimal getCostTotal() {
        return costTotal;
    }

    /**
     * 造价合计
     */
    public void setCostTotal(java.math.BigDecimal costTotal) {
        this.costTotal = costTotal;
    }
    /**
     * 人工费合计
     */
    public java.math.BigDecimal getLaborTotal() {
        return laborTotal;
    }

    /**
     * 人工费合计
     */
    public void setLaborTotal(java.math.BigDecimal laborTotal) {
        this.laborTotal = laborTotal;
    }
    /**
     * 材料费合计
     */
    public java.math.BigDecimal getMaterialTotal() {
        return materialTotal;
    }

    /**
     * 材料费合计
     */
    public void setMaterialTotal(java.math.BigDecimal materialTotal) {
        this.materialTotal = materialTotal;
    }
    /**
     * 机械费合计
     */
    public java.math.BigDecimal getMechanicalTotal() {
        return mechanicalTotal;
    }

    /**
     * 机械费合计
     */
    public void setMechanicalTotal(java.math.BigDecimal mechanicalTotal) {
        this.mechanicalTotal = mechanicalTotal;
    }
    /**
     * 企业管理费合计
     */
    public java.math.BigDecimal getManagementTotal() {
        return managementTotal;
    }

    /**
     * 企业管理费合计
     */
    public void setManagementTotal(java.math.BigDecimal managementTotal) {
        this.managementTotal = managementTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 利润合计
     */
    public java.math.BigDecimal getProfitsTotal() {
        return profitsTotal;
    }

    /**
     * 利润合计
     */
    public void setProfitsTotal(java.math.BigDecimal profitsTotal) {
        this.profitsTotal = profitsTotal;
    }
    
     /**
      * 限额设计子表
      */
     public List<QuotadesigndetailVO> getQuotadesigndetailEntities() {
        return quotadesigndetailEntities;
     }

     /**
      * 限额设计子表
      */
     public void setQuotadesigndetailEntities(List<QuotadesigndetailVO> quotadesigndetailEntities) {
        this.quotadesigndetailEntities = quotadesigndetailEntities;
     }

    public List<RecordquotadesignVO> getRecordquotadesignList() {
        return recordquotadesignList;
    }

    public void setRecordquotadesignList(List<RecordquotadesignVO> recordquotadesignList) {
        this.recordquotadesignList = recordquotadesignList;
    }

    /**
     * 内码
     * @return
     */
    public String getInnercode() {
        return innercode;
    }

    /**
     * 内码
     * @param innercode
     */
    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20220330.112743-39-sources.jar: com/ejianc/business/bedget/vo/QuotadesignVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.record.vo.RecordQuotaanalysisVO;
import com.ejianc.business.record.vo.RecordquotadesignVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bedget.vo.QuotadesigndetailVO;

/**
 * 限额设计表
 * 
 * @author generator
 * 
 */
public class QuotadesignVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.Long operatorId; // 经办人id
    private java.lang.String operatorName; // 经办人名称
    private java.math.BigDecimal costTotal; // 造价合计
    private java.math.BigDecimal laborTotal; // 人工费合计
    private java.math.BigDecimal materialTotal; // 材料费合计
    private java.math.BigDecimal mechanicalTotal; // 机械费合计
    private java.math.BigDecimal managementTotal; // 企业管理费合计
    private java.math.BigDecimal feesTotal; // 规费合计
    private java.math.BigDecimal taxTotal; // 税金合计
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.math.BigDecimal profitsTotal; // 利润合计

    private java.lang.String sort;
    private java.lang.String createTimeShow;
    private java.lang.String billStateStr;
    
    private List<QuotadesigndetailVO> quotadesigndetailEntities = new ArrayList<>(); // 限额设计子表
    private List<RecordquotadesignVO> recordquotadesignList = new ArrayList<>(); // 历史信息

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 造价合计
     */
    public java.math.BigDecimal getCostTotal() {
        return costTotal;
    }

    /**
     * 造价合计
     */
    public void setCostTotal(java.math.BigDecimal costTotal) {
        this.costTotal = costTotal;
    }
    /**
     * 人工费合计
     */
    public java.math.BigDecimal getLaborTotal() {
        return laborTotal;
    }

    /**
     * 人工费合计
     */
    public void setLaborTotal(java.math.BigDecimal laborTotal) {
        this.laborTotal = laborTotal;
    }
    /**
     * 材料费合计
     */
    public java.math.BigDecimal getMaterialTotal() {
        return materialTotal;
    }

    /**
     * 材料费合计
     */
    public void setMaterialTotal(java.math.BigDecimal materialTotal) {
        this.materialTotal = materialTotal;
    }
    /**
     * 机械费合计
     */
    public java.math.BigDecimal getMechanicalTotal() {
        return mechanicalTotal;
    }

    /**
     * 机械费合计
     */
    public void setMechanicalTotal(java.math.BigDecimal mechanicalTotal) {
        this.mechanicalTotal = mechanicalTotal;
    }
    /**
     * 企业管理费合计
     */
    public java.math.BigDecimal getManagementTotal() {
        return managementTotal;
    }

    /**
     * 企业管理费合计
     */
    public void setManagementTotal(java.math.BigDecimal managementTotal) {
        this.managementTotal = managementTotal;
    }
    /**
     * 规费合计
     */
    public java.math.BigDecimal getFeesTotal() {
        return feesTotal;
    }

    /**
     * 规费合计
     */
    public void setFeesTotal(java.math.BigDecimal feesTotal) {
        this.feesTotal = feesTotal;
    }
    /**
     * 税金合计
     */
    public java.math.BigDecimal getTaxTotal() {
        return taxTotal;
    }

    /**
     * 税金合计
     */
    public void setTaxTotal(java.math.BigDecimal taxTotal) {
        this.taxTotal = taxTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 利润合计
     */
    public java.math.BigDecimal getProfitsTotal() {
        return profitsTotal;
    }

    /**
     * 利润合计
     */
    public void setProfitsTotal(java.math.BigDecimal profitsTotal) {
        this.profitsTotal = profitsTotal;
    }
    
     /**
      * 限额设计子表
      */
     public List<QuotadesigndetailVO> getQuotadesigndetailEntities() {
        return quotadesigndetailEntities;
     }

     /**
      * 限额设计子表
      */
     public void setQuotadesigndetailEntities(List<QuotadesigndetailVO> quotadesigndetailEntities) {
        this.quotadesigndetailEntities = quotadesigndetailEntities;
     }

    public List<RecordquotadesignVO> getRecordquotadesignList() {
        return recordquotadesignList;
    }

    public void setRecordquotadesignList(List<RecordquotadesignVO> recordquotadesignList) {
        this.recordquotadesignList = recordquotadesignList;
    }
}
